# <span class="badge package-variant-dataquery"></span> loki

## Objects

 * <span class="badge object-type-enum"></span> [LokiQueryDirection](./object-LokiQueryDirection.md)
 * <span class="badge object-type-enum"></span> [LokiQueryType](./object-LokiQueryType.md)
 * <span class="badge object-type-enum"></span> [QueryEditorMode](./object-QueryEditorMode.md)
 * <span class="badge object-type-enum"></span> [SupportingQueryType](./object-SupportingQueryType.md)
 * <span class="badge object-type-class"></span> [Dataquery](./object-Dataquery.md)
## Builders

 * <span class="badge builder"></span> [Dataquery](./builder-Dataquery.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to loki data queries.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.DataqueryConfig
```

